#!/usr/bin/env bash
set -e

# Clean-up /tmp directory from files which might have remained from previous container restart
# We ignore any errors which might be caused by files injected by different agents which we do not have the rights to delete
rm -rfv /tmp/* || true

if [ -f /opt/topic-operator/custom-config/log4j2.properties ];
then
    export JAVA_OPTS="${JAVA_OPTS} -Dlog4j2.configurationFile=file:/opt/topic-operator/custom-config/log4j2.properties"
fi

if [ -n "$STRIMZI_JAVA_SYSTEM_PROPERTIES" ]; then
    export JAVA_OPTS="${JAVA_OPTS} ${STRIMZI_JAVA_SYSTEM_PROPERTIES}"
fi

if [ -n "$STRIMZI_JAVA_OPTS" ]; then
    export JAVA_OPTS="${JAVA_OPTS} ${STRIMZI_JAVA_OPTS}"
fi

if [ "$STRIMZI_TLS_ENABLED" = "true" ] || [ "$STRIMZI_SECURITY_PROTOCOL" = "SSL" ] || [ "$STRIMZI_SECURITY_PROTOCOL" = "SASL_SSL" ]; then
    # Generate temporary keystore password
    CERTS_STORE_PASSWORD=$(< /dev/urandom tr -dc _A-Z-a-z-0-9 | head -c32)
    export CERTS_STORE_PASSWORD

    mkdir -p /tmp/topic-operator

    # Import certificates into keystore and truststore
    "${STRIMZI_HOME}/bin/tls_prepare_certificates.sh"

    if [ "$STRIMZI_PUBLIC_CA" != "true" ]; then
        if [ -z "$STRIMZI_TRUSTSTORE_LOCATION" ]; then
            export STRIMZI_TRUSTSTORE_LOCATION=/tmp/topic-operator/replication.truststore.p12
            export STRIMZI_TRUSTSTORE_PASSWORD="$CERTS_STORE_PASSWORD"
        fi
    fi

    if [ "$STRIMZI_TLS_AUTH_ENABLED" != "false" ]; then
        if [ -z "$STRIMZI_KEYSTORE_LOCATION" ]; then
            export STRIMZI_KEYSTORE_LOCATION=/tmp/topic-operator/replication.keystore.p12
            export STRIMZI_KEYSTORE_PASSWORD="$CERTS_STORE_PASSWORD"
        fi
    fi
fi

export JAVA_CLASSPATH=$JAVA_CLASSPATH:lib/io.strimzi.topic-operator-0.45.0.jar:lib/io.strimzi.api-0.45.0.jar:lib/io.fabric8.kubernetes-model-networking-6.13.4.jar:lib/io.fabric8.kubernetes-model-common-6.13.4.jar:lib/io.fabric8.kubernetes-model-apiextensions-6.13.4.jar:lib/io.fabric8.kubernetes-client-6.13.4.jar:lib/io.fabric8.zjsonpatch-0.3.0.jar:lib/io.fabric8.kubernetes-httpclient-jdk-6.13.4.jar:lib/io.fabric8.kubernetes-client-api-6.13.4.jar:lib/io.fabric8.kubernetes-model-gatewayapi-6.13.4.jar:lib/io.fabric8.kubernetes-model-resource-6.13.4.jar:lib/io.fabric8.kubernetes-model-rbac-6.13.4.jar:lib/io.fabric8.kubernetes-model-admissionregistration-6.13.4.jar:lib/io.fabric8.kubernetes-model-apps-6.13.4.jar:lib/io.fabric8.kubernetes-model-autoscaling-6.13.4.jar:lib/io.fabric8.kubernetes-model-batch-6.13.4.jar:lib/io.fabric8.kubernetes-model-certificates-6.13.4.jar:lib/io.fabric8.kubernetes-model-coordination-6.13.4.jar:lib/io.fabric8.kubernetes-model-discovery-6.13.4.jar:lib/io.fabric8.kubernetes-model-events-6.13.4.jar:lib/io.fabric8.kubernetes-model-extensions-6.13.4.jar:lib/io.fabric8.kubernetes-model-flowcontrol-6.13.4.jar:lib/io.fabric8.kubernetes-model-metrics-6.13.4.jar:lib/io.fabric8.kubernetes-model-policy-6.13.4.jar:lib/io.fabric8.kubernetes-model-scheduling-6.13.4.jar:lib/io.fabric8.kubernetes-model-storageclass-6.13.4.jar:lib/io.fabric8.kubernetes-model-node-6.13.4.jar:lib/org.slf4j.slf4j-api-1.7.36.jar:lib/org.snakeyaml.snakeyaml-engine-2.7.jar:lib/com.fasterxml.jackson.dataformat.jackson-dataformat-yaml-2.16.2.jar:lib/org.yaml.snakeyaml-2.2.jar:lib/com.fasterxml.jackson.datatype.jackson-datatype-jsr310-2.16.2.jar:lib/io.fabric8.kubernetes-model-core-6.13.4.jar:lib/org.apache.logging.log4j.log4j-api-2.17.2.jar:lib/org.apache.logging.log4j.log4j-core-2.17.2.jar:lib/org.apache.logging.log4j.log4j-slf4j-impl-2.17.2.jar:lib/org.apache.kafka.kafka-clients-3.9.0.jar:lib/com.github.luben.zstd-jni-1.5.6-4.jar:lib/org.lz4.lz4-java-1.8.0.jar:lib/com.fasterxml.jackson.core.jackson-core-2.16.2.jar:lib/com.fasterxml.jackson.core.jackson-databind-2.16.2.jar:lib/com.fasterxml.jackson.core.jackson-annotations-2.16.2.jar:lib/io.strimzi.operator-common-0.45.0.jar:lib/io.strimzi.crd-annotations-0.45.0.jar:lib/org.quartz-scheduler.quartz-2.3.2.jar:lib/org.eclipse.jetty.jetty-server-9.4.56.v20240826.jar:lib/org.eclipse.jetty.jetty-http-9.4.56.v20240826.jar:lib/org.eclipse.jetty.jetty-util-9.4.56.v20240826.jar:lib/org.eclipse.jetty.jetty-io-9.4.56.v20240826.jar:lib/javax.servlet.javax.servlet-api-3.1.0.jar:lib/io.micrometer.micrometer-core-1.12.3.jar:lib/io.micrometer.micrometer-commons-1.12.3.jar:lib/io.micrometer.micrometer-observation-1.12.3.jar:lib/org.hdrhistogram.HdrHistogram-2.1.12.jar:lib/org.latencyutils.LatencyUtils-2.0.3.jar:lib/io.micrometer.micrometer-registry-prometheus-1.12.3.jar:lib/io.prometheus.simpleclient_common-0.16.0.jar:lib/io.prometheus.simpleclient-0.16.0.jar:lib/io.prometheus.simpleclient_tracer_otel-0.16.0.jar:lib/io.prometheus.simpleclient_tracer_common-0.16.0.jar:lib/io.prometheus.simpleclient_tracer_otel_agent-0.16.0.jar
export JAVA_MAIN=io.strimzi.operator.topic.TopicOperatorMain

export STRIMZI_KAFKA_BOOTSTRAP_SERVERS=$MSFT_KAFKA_REPLICATION_BOOTSTRAP
echo "Overrode kafka bootstrap for microsoft: $STRIMZI_KAFKA_BOOTSTRAP_SERVERS"

exec "${STRIMZI_HOME}/bin/launch_java.sh"
